@@ -67,14 +67,14 @@ class Application(Gtk.Application):
         aboutAction.connect('activate', self.about)
         self.add_action(aboutAction)
 
+        helpAction = Gio.SimpleAction.new('help', None)
+        helpAction.connect('activate', self.help)
+        self.add_action(helpAction)
+
         newPlaylistAction = Gio.SimpleAction.new('newPlaylist', None)
         newPlaylistAction.connect('activate', self.new_playlist)
         self.add_action(newPlaylistAction)
 
-        nowPlayingAction = Gio.SimpleAction.new('nowPlaying', None)
-        nowPlayingAction.connect('activate', self.now_playing)
-        self.add_action(nowPlayingAction)
-
         quitAction = Gio.SimpleAction.new('quit', None)
         quitAction.connect('activate', self.quit)
         self.add_action(quitAction)
@@ -82,8 +82,8 @@ class Application(Gtk.Application):
     def new_playlist(self, action, param):
         pass
 
-    def now_playing(self, action, param):
-        pass
+    def help(self, action, param):
+        Gtk.show_uri(None, "help:gnome-music", Gdk.CURRENT_TIME)
 
     def about(self, action, param):
         builder = Gtk.Builder()
